# not-my-board

[![on-push](https://github.com/holesch/not-my-board/actions/workflows/on-push.yml/badge.svg)](https://github.com/holesch/not-my-board/actions/workflows/on-push.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/not-my-board)](https://pypi.org/project/not-my-board/)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fholesch%2Fnot-my-board%2Fmaster%2Fpyproject.toml)
![PyPI - Status](https://img.shields.io/pypi/status/not-my-board)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

not-my-board is a tool to manage a pool of embedded hardware setups and to
schedule and provide access to those setups over a local network. The concept is
known as a *board farm*.

Check out the **[Documentation]** for installation and usage information.

[Documentation]: http://not-my-board.readthedocs.io
